=======
Credits
=======

Development Lead
----------------

* Hernan Valdivieso <hfvaldivieso@uc.cl> (The guy who wrote everything!)
* Wai Lam Jonathan Lee <jonathan.wailam.lee@gmail.com>

Contributors
------------

* TKasekamp
